@@ -86,7 +86,9 @@ sub prompt {
 	$msg .= " [$default]" if $showdefault;
 	$msg .= "$char ";
 
-	my $term = $App::PhotoDB::term;
+	# Create terminal handler
+	my $term = &term;
+
 	my $rv;
 	# Repeatedly prompt user until we get a response of the correct type
 	do {
